[Bug 1807] New: wsfb driver should run on NetBSD

bugzilla-daemon at freedesktop.org bugzilla-daemon at freedesktop.org
Tue Nov 9 11:27:55 PST 2004


Please do not reply to this email: if you want to comment on the bug, go to          
the URL shown below and enter yourcomments there.   
 
https://freedesktop.org/bugzilla/show_bug.cgi?id=1807        
   
           Summary: wsfb driver should run on NetBSD
           Product: xorg
           Version: CVS_head
          Platform: All
        OS/Version: NetBSD
            Status: NEW
          Severity: normal
          Priority: P2
         Component: Driver/other
        AssignedTo: xorg-bugzilla-noise at freedesktop.org
        ReportedBy: nathanw at mit.edu


The wsfb driver works fine on NetBSD systems with wscons raw framebuffers. It
should permit NetBSD in its runtime OS check.

--- wsfb_driver.c.orig  2004-11-09 14:18:51.000000000 -0500
+++ wsfb_driver.c       2004-11-09 14:21:03.000000000 -0500
@@ -200,9 +200,10 @@
        static Bool setupDone = FALSE;
        const char *osname;
 
        /* Check that we're being loaded on a OpenBSD system */
        LoaderGetOS(&osname, NULL, NULL, NULL);
-       if (!osname || strcmp(osname, "openbsd") != 0) {
+       if (!osname || (strcmp(osname, "openbsd") != 0 &&
+                       strcmp(osname, "netbsd") != 0)) {
                if (errmaj)
                        *errmaj = LDR_BADOS;
                if (errmin)        
   
   
--         
Configure bugmail: https://freedesktop.org/bugzilla/userprefs.cgi?tab=email       
   
------- You are receiving this mail because: -------
@@ -200,9 +200,10 @@
        const char *osname;
 
-       /* Check that we're being loaded on a OpenBSD system */
+       /* Check that we're being loaded on a OpenBSD or NetBSD system */
        LoaderGetOS(&osname, NULL, NULL, NULL);
You are the assignee for the bug, or are watching the assignee.


More information about the xorg-bugzilla-noise mailing list